"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.interfaces.v1.history_pb2
import bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CardModuleType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CardModuleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CardModuleType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Module_invalid: _CardModuleType.ValueType  # 0
    Module_header: _CardModuleType.ValueType  # 1
    Module_archive: _CardModuleType.ValueType  # 2
    Module_cbtn: _CardModuleType.ValueType  # 3

class CardModuleType(_CardModuleType, metaclass=_CardModuleTypeEnumTypeWrapper):
    """"""

Module_invalid: CardModuleType.ValueType  # 0
Module_header: CardModuleType.ValueType  # 1
Module_archive: CardModuleType.ValueType  # 2
Module_cbtn: CardModuleType.ValueType  # 3
global___CardModuleType = CardModuleType

class _ListOrder:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ListOrderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ListOrder.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NO_ORDER: _ListOrder.ValueType  # 0
    """"""
    ORDER_NORMAL: _ListOrder.ValueType  # 1
    """"""
    ORDER_REVERSE: _ListOrder.ValueType  # 2
    """"""
    ORDER_RANDOM: _ListOrder.ValueType  # 3
    """"""

class ListOrder(_ListOrder, metaclass=_ListOrderEnumTypeWrapper):
    """"""

NO_ORDER: ListOrder.ValueType  # 0
""""""
ORDER_NORMAL: ListOrder.ValueType  # 1
""""""
ORDER_REVERSE: ListOrder.ValueType  # 2
""""""
ORDER_RANDOM: ListOrder.ValueType  # 3
""""""
global___ListOrder = ListOrder

class _ListSortField:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ListSortFieldEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ListSortField.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NO_SORT: _ListSortField.ValueType  # 0
    """"""
    SORT_CTIME: _ListSortField.ValueType  # 1
    """"""
    SORT_VIEWCNT: _ListSortField.ValueType  # 2
    """"""
    SORT_FAVCNT: _ListSortField.ValueType  # 3
    """"""

class ListSortField(_ListSortField, metaclass=_ListSortFieldEnumTypeWrapper):
    """"""

NO_SORT: ListSortField.ValueType  # 0
""""""
SORT_CTIME: ListSortField.ValueType  # 1
""""""
SORT_VIEWCNT: ListSortField.ValueType  # 2
""""""
SORT_FAVCNT: ListSortField.ValueType  # 3
""""""
global___ListSortField = ListSortField

class _PlaylistSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlaylistSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlaylistSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _PlaylistSource.ValueType  # 0
    """"""
    MEM_SPACE: _PlaylistSource.ValueType  # 1
    """"""
    AUDIO_COLLECTION: _PlaylistSource.ValueType  # 2
    """"""
    AUDIO_CARD: _PlaylistSource.ValueType  # 3
    """"""
    USER_FAVOURITE: _PlaylistSource.ValueType  # 4
    """"""
    UP_ARCHIVE: _PlaylistSource.ValueType  # 5
    """"""
    AUDIO_CACHE: _PlaylistSource.ValueType  # 6
    """"""
    PICK_CARD: _PlaylistSource.ValueType  # 7
    """"""
    MEDIA_LIST: _PlaylistSource.ValueType  # 8
    """"""

class PlaylistSource(_PlaylistSource, metaclass=_PlaylistSourceEnumTypeWrapper):
    """"""

DEFAULT: PlaylistSource.ValueType  # 0
""""""
MEM_SPACE: PlaylistSource.ValueType  # 1
""""""
AUDIO_COLLECTION: PlaylistSource.ValueType  # 2
""""""
AUDIO_CARD: PlaylistSource.ValueType  # 3
""""""
USER_FAVOURITE: PlaylistSource.ValueType  # 4
""""""
UP_ARCHIVE: PlaylistSource.ValueType  # 5
""""""
AUDIO_CACHE: PlaylistSource.ValueType  # 6
""""""
PICK_CARD: PlaylistSource.ValueType  # 7
""""""
MEDIA_LIST: PlaylistSource.ValueType  # 8
""""""
global___PlaylistSource = PlaylistSource

class _TopCardType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSPECIFIED: _TopCardType.ValueType  # 0
    """"""
    LISTEN_HISTORY: _TopCardType.ValueType  # 1
    """"""
    FAVORITE_FOLDER: _TopCardType.ValueType  # 2
    """"""
    UP_RECALL: _TopCardType.ValueType  # 3
    """"""
    PICK_TODAY: _TopCardType.ValueType  # 4
    """"""

class TopCardType(_TopCardType, metaclass=_TopCardTypeEnumTypeWrapper):
    """"""

UNSPECIFIED: TopCardType.ValueType  # 0
""""""
LISTEN_HISTORY: TopCardType.ValueType  # 1
""""""
FAVORITE_FOLDER: TopCardType.ValueType  # 2
""""""
UP_RECALL: TopCardType.ValueType  # 3
""""""
PICK_TODAY: TopCardType.ValueType  # 4
""""""
global___TopCardType = TopCardType

@typing_extensions.final
class Author(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    avatar: builtins.str
    """"""
    @property
    def relation(self) -> global___FollowRelation:
        """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        avatar: builtins.str = ...,
        relation: global___FollowRelation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "mid", b"mid", "name", b"name", "relation", b"relation"]) -> None: ...

global___Author = Author

@typing_extensions.final
class BKArcDetailsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    PLAYERARGS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayItem]:
        """"""
    @property
    def playerArgs(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___PlayItem] | None = ...,
        playerArgs: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["playerArgs", b"playerArgs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "playerArgs", b"playerArgs"]) -> None: ...

global___BKArcDetailsReq = BKArcDetailsReq

@typing_extensions.final
class BKArcDetailsResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetailItem]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DetailItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___BKArcDetailsResp = BKArcDetailsResp

@typing_extensions.final
class BKArchive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    DISPLAYED_OID_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    desc: builtins.str
    """"""
    duration: builtins.int
    """"""
    rid: builtins.int
    """"""
    rname: builtins.str
    """"""
    publish: builtins.int
    """"""
    displayed_oid: builtins.str
    """"""
    copyright: builtins.int
    """"""
    @property
    def rights(self) -> global___BKArcRights:
        """"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        desc: builtins.str = ...,
        duration: builtins.int = ...,
        rid: builtins.int = ...,
        rname: builtins.str = ...,
        publish: builtins.int = ...,
        displayed_oid: builtins.str = ...,
        copyright: builtins.int = ...,
        rights: global___BKArcRights | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rights", b"rights"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["copyright", b"copyright", "cover", b"cover", "desc", b"desc", "displayed_oid", b"displayed_oid", "duration", b"duration", "oid", b"oid", "publish", b"publish", "rid", b"rid", "rights", b"rights", "rname", b"rname", "title", b"title"]) -> None: ...

global___BKArchive = BKArchive

@typing_extensions.final
class BKArcPart(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    SUB_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """"""
    sub_id: builtins.int
    """"""
    title: builtins.str
    """"""
    duration: builtins.int
    """"""
    page: builtins.int
    """"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        sub_id: builtins.int = ...,
        title: builtins.str = ...,
        duration: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "oid", b"oid", "page", b"page", "sub_id", b"sub_id", "title", b"title"]) -> None: ...

global___BKArcPart = BKArcPart

@typing_extensions.final
class BKArcRights(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NO_REPRINT_FIELD_NUMBER: builtins.int
    no_reprint: builtins.int
    """"""
    def __init__(
        self,
        *,
        no_reprint: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["no_reprint", b"no_reprint"]) -> None: ...

global___BKArcRights = BKArcRights

@typing_extensions.final
class BKStat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    FAVOURITE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    HAS_LIKE_FIELD_NUMBER: builtins.int
    HAS_COIN_FIELD_NUMBER: builtins.int
    HAS_FAV_FIELD_NUMBER: builtins.int
    like: builtins.int
    """"""
    coin: builtins.int
    """"""
    favourite: builtins.int
    """"""
    reply: builtins.int
    """"""
    share: builtins.int
    """"""
    view: builtins.int
    """"""
    has_like: builtins.bool
    """"""
    has_coin: builtins.bool
    """"""
    has_fav: builtins.bool
    """"""
    def __init__(
        self,
        *,
        like: builtins.int = ...,
        coin: builtins.int = ...,
        favourite: builtins.int = ...,
        reply: builtins.int = ...,
        share: builtins.int = ...,
        view: builtins.int = ...,
        has_like: builtins.bool = ...,
        has_coin: builtins.bool = ...,
        has_fav: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin", b"coin", "favourite", b"favourite", "has_coin", b"has_coin", "has_fav", b"has_fav", "has_like", b"has_like", "like", b"like", "reply", b"reply", "share", b"share", "view", b"view"]) -> None: ...

global___BKStat = BKStat

@typing_extensions.final
class CardModule(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_HEADER_FIELD_NUMBER: builtins.int
    MODULE_ARCHIVE_FIELD_NUMBER: builtins.int
    MODULE_CBTN_FIELD_NUMBER: builtins.int
    module_type: builtins.int
    """"""
    @property
    def module_header(self) -> global___PkcmHeader:
        """"""
    @property
    def module_archive(self) -> global___PkcmArchive:
        """"""
    @property
    def module_cbtn(self) -> global___PkcmCenterButton:
        """"""
    def __init__(
        self,
        *,
        module_type: builtins.int = ...,
        module_header: global___PkcmHeader | None = ...,
        module_archive: global___PkcmArchive | None = ...,
        module_cbtn: global___PkcmCenterButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module", b"module", "module_archive", b"module_archive", "module_cbtn", b"module_cbtn", "module_header", b"module_header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module", b"module", "module_archive", b"module_archive", "module_cbtn", b"module_cbtn", "module_header", b"module_header", "module_type", b"module_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module", b"module"]) -> typing_extensions.Literal["module_header", "module_archive", "module_cbtn"] | None: ...

global___CardModule = CardModule

@typing_extensions.final
class ClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        sid: builtins.int = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "sid", b"sid"]) -> None: ...

global___ClickReq = ClickReq

@typing_extensions.final
class ClickResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ClickResp = ClickResp

@typing_extensions.final
class CoinAddReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    THUMB_UP_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    num: builtins.int
    """"""
    thumb_up: builtins.bool
    """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        num: builtins.int = ...,
        thumb_up: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "num", b"num", "thumb_up", b"thumb_up"]) -> None: ...

global___CoinAddReq = CoinAddReq

@typing_extensions.final
class CoinAddResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___CoinAddResp = CoinAddResp

@typing_extensions.final
class DashItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    CODECS_FIELD_NUMBER: builtins.int
    SEGMENT_BASE_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    base_url: builtins.str
    """"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    bandwidth: builtins.int
    """"""
    mime_type: builtins.str
    """"""
    codecs: builtins.str
    """"""
    @property
    def segment_base(self) -> global___DashSegmentBase:
        """"""
    codecid: builtins.int
    """"""
    md5: builtins.str
    """"""
    size: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        base_url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        mime_type: builtins.str = ...,
        codecs: builtins.str = ...,
        segment_base: global___DashSegmentBase | None = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["segment_base", b"segment_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "bandwidth", b"bandwidth", "base_url", b"base_url", "codecid", b"codecid", "codecs", b"codecs", "id", b"id", "md5", b"md5", "mime_type", b"mime_type", "segment_base", b"segment_base", "size", b"size"]) -> None: ...

global___DashItem = DashItem

@typing_extensions.final
class DashSegmentBase(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INITIALIZATION_FIELD_NUMBER: builtins.int
    INDEX_RANGE_FIELD_NUMBER: builtins.int
    initialization: builtins.str
    """"""
    index_range: builtins.str
    """"""
    def __init__(
        self,
        *,
        initialization: builtins.str = ...,
        index_range: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["index_range", b"index_range", "initialization", b"initialization"]) -> None: ...

global___DashSegmentBase = DashSegmentBase

@typing_extensions.final
class DetailItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlayerInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___PlayInfo: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___PlayInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ITEM_FIELD_NUMBER: builtins.int
    ARC_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    LAST_PART_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    PLAYABLE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    PLAYER_INFO_FIELD_NUMBER: builtins.int
    ASSOCIATED_ITEM_FIELD_NUMBER: builtins.int
    LAST_PLAY_TIME_FIELD_NUMBER: builtins.int
    HISTORY_TAG_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    UGC_SEASON_INFO_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    @property
    def arc(self) -> global___BKArchive:
        """"""
    @property
    def parts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BKArcPart]:
        """"""
    @property
    def owner(self) -> global___Author:
        """"""
    @property
    def stat(self) -> global___BKStat:
        """"""
    last_part: builtins.int
    """"""
    progress: builtins.int
    """"""
    playable: builtins.int
    """"""
    message: builtins.str
    """"""
    @property
    def player_info(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___PlayInfo]:
        """"""
    @property
    def associated_item(self) -> global___PlayItem:
        """"""
    last_play_time: builtins.int
    """"""
    history_tag: builtins.str
    """"""
    @property
    def device_type(self) -> bilireq.grpc.protos.bilibili.app.interfaces.v1.history_pb2.DeviceType:
        """"""
    @property
    def ugc_season_info(self) -> global___FavFolder:
        """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        arc: global___BKArchive | None = ...,
        parts: collections.abc.Iterable[global___BKArcPart] | None = ...,
        owner: global___Author | None = ...,
        stat: global___BKStat | None = ...,
        last_part: builtins.int = ...,
        progress: builtins.int = ...,
        playable: builtins.int = ...,
        message: builtins.str = ...,
        player_info: collections.abc.Mapping[builtins.int, global___PlayInfo] | None = ...,
        associated_item: global___PlayItem | None = ...,
        last_play_time: builtins.int = ...,
        history_tag: builtins.str = ...,
        device_type: bilireq.grpc.protos.bilibili.app.interfaces.v1.history_pb2.DeviceType | None = ...,
        ugc_season_info: global___FavFolder | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc", "associated_item", b"associated_item", "device_type", b"device_type", "item", b"item", "owner", b"owner", "stat", b"stat", "ugc_season_info", b"ugc_season_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "associated_item", b"associated_item", "device_type", b"device_type", "history_tag", b"history_tag", "item", b"item", "last_part", b"last_part", "last_play_time", b"last_play_time", "message", b"message", "owner", b"owner", "parts", b"parts", "playable", b"playable", "player_info", b"player_info", "progress", b"progress", "stat", b"stat", "ugc_season_info", b"ugc_season_info"]) -> None: ...

global___DetailItem = DetailItem

@typing_extensions.final
class EventReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_TYPE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    event_type: builtins.int
    """"""
    @property
    def item(self) -> global___PlayItem:
        """"""
    def __init__(
        self,
        *,
        event_type: builtins.int = ...,
        item: global___PlayItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_type", b"event_type", "item", b"item"]) -> None: ...

global___EventReq = EventReq

@typing_extensions.final
class EventResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EventResp = EventResp

@typing_extensions.final
class EventTracking(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_FIELD_NUMBER: builtins.int
    BATCH_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    ENTITY_TYPE_FIELD_NUMBER: builtins.int
    ENTITY_ID_FIELD_NUMBER: builtins.int
    TRACK_JSON_FIELD_NUMBER: builtins.int
    operator: builtins.str
    """"""
    batch: builtins.str
    """"""
    track_id: builtins.str
    """"""
    entity_type: builtins.str
    """"""
    entity_id: builtins.str
    """"""
    track_json: builtins.str
    """"""
    def __init__(
        self,
        *,
        operator: builtins.str = ...,
        batch: builtins.str = ...,
        track_id: builtins.str = ...,
        entity_type: builtins.str = ...,
        entity_id: builtins.str = ...,
        track_json: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch", b"batch", "entity_id", b"entity_id", "entity_type", b"entity_type", "operator", b"operator", "track_id", b"track_id", "track_json", b"track_json"]) -> None: ...

global___EventTracking = EventTracking

@typing_extensions.final
class FavFolder(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    FAVORED_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    STAT_FAV_CNT_FIELD_NUMBER: builtins.int
    STAT_SHARE_CNT_FIELD_NUMBER: builtins.int
    STAT_LIKE_CNT_FIELD_NUMBER: builtins.int
    STAT_PLAY_CNT_FIELD_NUMBER: builtins.int
    STAT_REPLY_CNT_FIELD_NUMBER: builtins.int
    FAV_STATE_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    @property
    def owner(self) -> global___FavFolderAuthor:
        """"""
    name: builtins.str
    """"""
    cover: builtins.str
    """"""
    desc: builtins.str
    """"""
    count: builtins.int
    """"""
    attr: builtins.int
    """"""
    state: builtins.int
    """"""
    favored: builtins.int
    """"""
    ctime: builtins.int
    """"""
    mtime: builtins.int
    """"""
    stat_fav_cnt: builtins.int
    """"""
    stat_share_cnt: builtins.int
    """"""
    stat_like_cnt: builtins.int
    """"""
    stat_Play_cnt: builtins.int
    """"""
    stat_reply_cnt: builtins.int
    """"""
    fav_state: builtins.int
    """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
        owner: global___FavFolderAuthor | None = ...,
        name: builtins.str = ...,
        cover: builtins.str = ...,
        desc: builtins.str = ...,
        count: builtins.int = ...,
        attr: builtins.int = ...,
        state: builtins.int = ...,
        favored: builtins.int = ...,
        ctime: builtins.int = ...,
        mtime: builtins.int = ...,
        stat_fav_cnt: builtins.int = ...,
        stat_share_cnt: builtins.int = ...,
        stat_like_cnt: builtins.int = ...,
        stat_Play_cnt: builtins.int = ...,
        stat_reply_cnt: builtins.int = ...,
        fav_state: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["owner", b"owner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attr", b"attr", "count", b"count", "cover", b"cover", "ctime", b"ctime", "desc", b"desc", "fav_state", b"fav_state", "favored", b"favored", "fid", b"fid", "folder_type", b"folder_type", "mtime", b"mtime", "name", b"name", "owner", b"owner", "stat_Play_cnt", b"stat_Play_cnt", "stat_fav_cnt", b"stat_fav_cnt", "stat_like_cnt", b"stat_like_cnt", "stat_reply_cnt", b"stat_reply_cnt", "stat_share_cnt", b"stat_share_cnt", "state", b"state"]) -> None: ...

global___FavFolder = FavFolder

@typing_extensions.final
class FavFolderAction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "fid", b"fid", "folder_type", b"folder_type"]) -> None: ...

global___FavFolderAction = FavFolderAction

@typing_extensions.final
class FavFolderAuthor(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "name", b"name"]) -> None: ...

global___FavFolderAuthor = FavFolderAuthor

@typing_extensions.final
class FavFolderCreateReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    desc: builtins.str
    """"""
    public: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        desc: builtins.str = ...,
        public: builtins.int = ...,
        folder_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "folder_type", b"folder_type", "name", b"name", "public", b"public"]) -> None: ...

global___FavFolderCreateReq = FavFolderCreateReq

@typing_extensions.final
class FavFolderCreateResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fid", b"fid", "folder_type", b"folder_type", "message", b"message"]) -> None: ...

global___FavFolderCreateResp = FavFolderCreateResp

@typing_extensions.final
class FavFolderDeleteReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fid", b"fid", "folder_type", b"folder_type"]) -> None: ...

global___FavFolderDeleteReq = FavFolderDeleteReq

@typing_extensions.final
class FavFolderDeleteResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___FavFolderDeleteResp = FavFolderDeleteResp

@typing_extensions.final
class FavFolderDetailReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    FAV_MID_FIELD_NUMBER: builtins.int
    LAST_ITEM_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    NEED_FOLDER_INFO_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    fav_mid: builtins.int
    """"""
    @property
    def last_item(self) -> global___FavItem:
        """"""
    page_size: builtins.int
    """"""
    need_folder_info: builtins.bool
    """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
        fav_mid: builtins.int = ...,
        last_item: global___FavItem | None = ...,
        page_size: builtins.int = ...,
        need_folder_info: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_item", b"last_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fav_mid", b"fav_mid", "fid", b"fid", "folder_type", b"folder_type", "last_item", b"last_item", "need_folder_info", b"need_folder_info", "page_size", b"page_size"]) -> None: ...

global___FavFolderDetailReq = FavFolderDetailReq

@typing_extensions.final
class FavFolderDetailResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    REACH_END_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    FOLDER_INFO_FIELD_NUMBER: builtins.int
    total: builtins.int
    """"""
    reach_end: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavItemDetail]:
        """"""
    @property
    def folder_info(self) -> global___FavFolder:
        """"""
    def __init__(
        self,
        *,
        total: builtins.int = ...,
        reach_end: builtins.bool = ...,
        list: collections.abc.Iterable[global___FavItemDetail] | None = ...,
        folder_info: global___FavFolder | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["folder_info", b"folder_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["folder_info", b"folder_info", "list", b"list", "reach_end", b"reach_end", "total", b"total"]) -> None: ...

global___FavFolderDetailResp = FavFolderDetailResp

@typing_extensions.final
class FavFolderListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_TYPES_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    @property
    def folder_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    @property
    def item(self) -> global___PlayItem:
        """"""
    def __init__(
        self,
        *,
        folder_types: collections.abc.Iterable[builtins.int] | None = ...,
        item: global___PlayItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["folder_types", b"folder_types", "item", b"item"]) -> None: ...

global___FavFolderListReq = FavFolderListReq

@typing_extensions.final
class FavFolderListResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavFolder]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___FavFolder] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___FavFolderListResp = FavFolderListResp

@typing_extensions.final
class FavFolderMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fid", b"fid", "folder_type", b"folder_type"]) -> None: ...

global___FavFolderMeta = FavFolderMeta

@typing_extensions.final
class FavItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    FID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    ET_FIELD_NUMBER: builtins.int
    item_type: builtins.int
    """"""
    oid: builtins.int
    """"""
    fid: builtins.int
    """"""
    mid: builtins.int
    """"""
    mtime: builtins.int
    """"""
    ctime: builtins.int
    """"""
    @property
    def et(self) -> global___EventTracking:
        """"""
    def __init__(
        self,
        *,
        item_type: builtins.int = ...,
        oid: builtins.int = ...,
        fid: builtins.int = ...,
        mid: builtins.int = ...,
        mtime: builtins.int = ...,
        ctime: builtins.int = ...,
        et: global___EventTracking | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["et", b"et"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ctime", b"ctime", "et", b"et", "fid", b"fid", "item_type", b"item_type", "mid", b"mid", "mtime", b"mtime", "oid", b"oid"]) -> None: ...

global___FavItem = FavItem

@typing_extensions.final
class FavItemAddReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    @property
    def play(self) -> global___PlayItem:
        """"""
    @property
    def fav(self) -> global___FavItem:
        """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
        play: global___PlayItem | None = ...,
        fav: global___FavItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav", b"fav", "item", b"item", "play", b"play"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fav", b"fav", "fid", b"fid", "folder_type", b"folder_type", "item", b"item", "play", b"play"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["play", "fav"] | None: ...

global___FavItemAddReq = FavItemAddReq

@typing_extensions.final
class FavItemAddResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___FavItemAddResp = FavItemAddResp

@typing_extensions.final
class FavItemAuthor(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "name", b"name"]) -> None: ...

global___FavItemAuthor = FavItemAuthor

@typing_extensions.final
class FavItemBatchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavFolderAction]:
        """"""
    @property
    def play(self) -> global___PlayItem:
        """"""
    @property
    def fav(self) -> global___FavItem:
        """"""
    def __init__(
        self,
        *,
        actions: collections.abc.Iterable[global___FavFolderAction] | None = ...,
        play: global___PlayItem | None = ...,
        fav: global___FavItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav", b"fav", "item", b"item", "play", b"play"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "fav", b"fav", "item", b"item", "play", b"play"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["play", "fav"] | None: ...

global___FavItemBatchReq = FavItemBatchReq

@typing_extensions.final
class FavItemBatchResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___FavItemBatchResp = FavItemBatchResp

@typing_extensions.final
class FavItemDelReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    @property
    def play(self) -> global___PlayItem:
        """"""
    @property
    def fav(self) -> global___FavItem:
        """"""
    def __init__(
        self,
        *,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
        play: global___PlayItem | None = ...,
        fav: global___FavItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav", b"fav", "item", b"item", "play", b"play"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fav", b"fav", "fid", b"fid", "folder_type", b"folder_type", "item", b"item", "play", b"play"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["play", "fav"] | None: ...

global___FavItemDelReq = FavItemDelReq

@typing_extensions.final
class FavItemDelResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___FavItemDelResp = FavItemDelResp

@typing_extensions.final
class FavItemDetail(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___FavItem:
        """"""
    @property
    def owner(self) -> global___FavItemAuthor:
        """"""
    @property
    def stat(self) -> global___FavItemStat:
        """"""
    cover: builtins.str
    """"""
    name: builtins.str
    """"""
    duration: builtins.int
    """"""
    state: builtins.int
    """"""
    message: builtins.str
    """"""
    parts: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___FavItem | None = ...,
        owner: global___FavItemAuthor | None = ...,
        stat: global___FavItemStat | None = ...,
        cover: builtins.str = ...,
        name: builtins.str = ...,
        duration: builtins.int = ...,
        state: builtins.int = ...,
        message: builtins.str = ...,
        parts: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "owner", b"owner", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "duration", b"duration", "item", b"item", "message", b"message", "name", b"name", "owner", b"owner", "parts", b"parts", "stat", b"stat", "state", b"state"]) -> None: ...

global___FavItemDetail = FavItemDetail

@typing_extensions.final
class FavItemStat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    view: builtins.int
    """"""
    reply: builtins.int
    """"""
    def __init__(
        self,
        *,
        view: builtins.int = ...,
        reply: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reply", b"reply", "view", b"view"]) -> None: ...

global___FavItemStat = FavItemStat

@typing_extensions.final
class FavoredInAnyFoldersReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_TYPES_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    @property
    def folder_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    @property
    def item(self) -> global___PlayItem:
        """"""
    def __init__(
        self,
        *,
        folder_types: collections.abc.Iterable[builtins.int] | None = ...,
        item: global___PlayItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["folder_types", b"folder_types", "item", b"item"]) -> None: ...

global___FavoredInAnyFoldersReq = FavoredInAnyFoldersReq

@typing_extensions.final
class FavoredInAnyFoldersResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDERS_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    @property
    def folders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavFolderMeta]:
        """"""
    @property
    def item(self) -> global___PlayItem:
        """"""
    def __init__(
        self,
        *,
        folders: collections.abc.Iterable[global___FavFolderMeta] | None = ...,
        item: global___PlayItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["folders", b"folders", "item", b"item"]) -> None: ...

global___FavoredInAnyFoldersResp = FavoredInAnyFoldersResp

@typing_extensions.final
class FavTabShowReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___FavTabShowReq = FavTabShowReq

@typing_extensions.final
class FavTabShowResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_MENU_FIELD_NUMBER: builtins.int
    show_menu: builtins.bool
    """"""
    def __init__(
        self,
        *,
        show_menu: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_menu", b"show_menu"]) -> None: ...

global___FavTabShowResp = FavTabShowResp

@typing_extensions.final
class FollowRelation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.int
    """"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___FollowRelation = FollowRelation

@typing_extensions.final
class FormatDescription(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """"""
    format: builtins.str
    """"""
    description: builtins.str
    """"""
    display_desc: builtins.str
    """"""
    superscript: builtins.str
    """"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        description: builtins.str = ...,
        display_desc: builtins.str = ...,
        superscript: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_desc", b"display_desc", "format", b"format", "quality", b"quality", "superscript", b"superscript"]) -> None: ...

global___FormatDescription = FormatDescription

@typing_extensions.final
class MainFavMusicMenuListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_TYPE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    tab_type: builtins.int
    """"""
    offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        tab_type: builtins.int = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset", b"offset", "tab_type", b"tab_type"]) -> None: ...

global___MainFavMusicMenuListReq = MainFavMusicMenuListReq

@typing_extensions.final
class MainFavMusicMenuListResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_TYPE_FIELD_NUMBER: builtins.int
    MENU_LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    tab_type: builtins.int
    """"""
    @property
    def menu_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MusicMenu]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        tab_type: builtins.int = ...,
        menu_list: collections.abc.Iterable[global___MusicMenu] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "menu_list", b"menu_list", "offset", b"offset", "tab_type", b"tab_type"]) -> None: ...

global___MainFavMusicMenuListResp = MainFavMusicMenuListResp

@typing_extensions.final
class MainFavMusicSubTabListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MainFavMusicSubTabListReq = MainFavMusicSubTabListReq

@typing_extensions.final
class MainFavMusicSubTabListResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class FirstPageResEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___MainFavMusicMenuListResp: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___MainFavMusicMenuListResp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TABS_FIELD_NUMBER: builtins.int
    DEFAULT_TAB_RES_FIELD_NUMBER: builtins.int
    FIRST_PAGE_RES_FIELD_NUMBER: builtins.int
    @property
    def tabs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MusicSubTab]:
        """"""
    @property
    def default_tab_res(self) -> global___MainFavMusicMenuListResp:
        """"""
    @property
    def first_page_res(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___MainFavMusicMenuListResp]:
        """"""
    def __init__(
        self,
        *,
        tabs: collections.abc.Iterable[global___MusicSubTab] | None = ...,
        default_tab_res: global___MainFavMusicMenuListResp | None = ...,
        first_page_res: collections.abc.Mapping[builtins.int, global___MainFavMusicMenuListResp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_tab_res", b"default_tab_res"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_tab_res", b"default_tab_res", "first_page_res", b"first_page_res", "tabs", b"tabs"]) -> None: ...

global___MainFavMusicSubTabListResp = MainFavMusicSubTabListResp

@typing_extensions.final
class MedialistItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    STAT_VIEW_FIELD_NUMBER: builtins.int
    STAT_REPLY_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    duration: builtins.int
    """"""
    parts: builtins.int
    """"""
    up_mid: builtins.int
    """"""
    up_name: builtins.str
    """"""
    state: builtins.int
    """"""
    message: builtins.str
    """"""
    stat_view: builtins.int
    """"""
    stat_reply: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        duration: builtins.int = ...,
        parts: builtins.int = ...,
        up_mid: builtins.int = ...,
        up_name: builtins.str = ...,
        state: builtins.int = ...,
        message: builtins.str = ...,
        stat_view: builtins.int = ...,
        stat_reply: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "duration", b"duration", "item", b"item", "message", b"message", "parts", b"parts", "stat_reply", b"stat_reply", "stat_view", b"stat_view", "state", b"state", "title", b"title", "up_mid", b"up_mid", "up_name", b"up_name"]) -> None: ...

global___MedialistItem = MedialistItem

@typing_extensions.final
class MedialistReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    list_type: builtins.int
    """"""
    biz_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    def __init__(
        self,
        *,
        list_type: builtins.int = ...,
        biz_id: builtins.int = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "list_type", b"list_type", "offset", b"offset"]) -> None: ...

global___MedialistReq = MedialistReq

@typing_extensions.final
class MedialistResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    UP_INFO_FIELD_NUMBER: builtins.int
    total: builtins.int
    """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MedialistItem]:
        """"""
    @property
    def up_info(self) -> global___MedialistUpInfo:
        """"""
    def __init__(
        self,
        *,
        total: builtins.int = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
        items: collections.abc.Iterable[global___MedialistItem] | None = ...,
        up_info: global___MedialistUpInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["up_info", b"up_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "items", b"items", "offset", b"offset", "total", b"total", "up_info", b"up_info"]) -> None: ...

global___MedialistResp = MedialistResp

@typing_extensions.final
class MedialistUpInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    avatar: builtins.str
    """"""
    fans: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        avatar: builtins.str = ...,
        fans: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "fans", b"fans", "mid", b"mid", "name", b"name"]) -> None: ...

global___MedialistUpInfo = MedialistUpInfo

@typing_extensions.final
class MenuDeleteReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___MenuDeleteReq = MenuDeleteReq

@typing_extensions.final
class MenuDeleteResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___MenuDeleteResp = MenuDeleteResp

@typing_extensions.final
class MenuEditReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    IS_PUBLIC_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    is_public: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        is_public: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "id", b"id", "is_public", b"is_public", "title", b"title"]) -> None: ...

global___MenuEditReq = MenuEditReq

@typing_extensions.final
class MenuEditResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___MenuEditResp = MenuEditResp

@typing_extensions.final
class MenuSubscribeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    TARGET_ID_FIELD_NUMBER: builtins.int
    action: builtins.int
    """"""
    target_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        action: builtins.int = ...,
        target_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "target_id", b"target_id"]) -> None: ...

global___MenuSubscribeReq = MenuSubscribeReq

@typing_extensions.final
class MenuSubscribeResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___MenuSubscribeResp = MenuSubscribeResp

@typing_extensions.final
class MusicMenu(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MENU_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    menu_type: builtins.int
    """"""
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    cover: builtins.str
    """"""
    @property
    def owner(self) -> global___MusicMenuAuthor:
        """"""
    state: builtins.int
    """"""
    attr: builtins.int
    """"""
    @property
    def stat(self) -> global___MusicMenuStat:
        """"""
    total: builtins.int
    """"""
    ctime: builtins.int
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        menu_type: builtins.int = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        owner: global___MusicMenuAuthor | None = ...,
        state: builtins.int = ...,
        attr: builtins.int = ...,
        stat: global___MusicMenuStat | None = ...,
        total: builtins.int = ...,
        ctime: builtins.int = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["owner", b"owner", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attr", b"attr", "cover", b"cover", "ctime", b"ctime", "desc", b"desc", "id", b"id", "menu_type", b"menu_type", "owner", b"owner", "stat", b"stat", "state", b"state", "title", b"title", "total", b"total", "uri", b"uri"]) -> None: ...

global___MusicMenu = MusicMenu

@typing_extensions.final
class MusicMenuAuthor(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    avatar: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        avatar: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "mid", b"mid", "name", b"name"]) -> None: ...

global___MusicMenuAuthor = MusicMenuAuthor

@typing_extensions.final
class MusicMenuStat(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    play: builtins.int
    """"""
    reply: builtins.int
    """"""
    def __init__(
        self,
        *,
        play: builtins.int = ...,
        reply: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["play", b"play", "reply", b"reply"]) -> None: ...

global___MusicMenuStat = MusicMenuStat

@typing_extensions.final
class MusicSubTab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TAB_TYPE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    tab_type: builtins.int
    """"""
    total: builtins.int
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tab_type: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tab_type", b"tab_type", "total", b"total"]) -> None: ...

global___MusicSubTab = MusicSubTab

@typing_extensions.final
class PageOption(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    LAST_ITEM_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """"""
    direction: builtins.int
    """"""
    @property
    def last_item(self) -> global___PlayItem:
        """"""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        direction: builtins.int = ...,
        last_item: global___PlayItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_item", b"last_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["direction", b"direction", "last_item", b"last_item", "page_size", b"page_size"]) -> None: ...

global___PageOption = PageOption

@typing_extensions.final
class PickArchive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    STAT_VIEW_FIELD_NUMBER: builtins.int
    STAT_REPLY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    title: builtins.str
    """"""
    @property
    def owner(self) -> global___PickArchiveAuthor:
        """"""
    cover: builtins.str
    """"""
    duration: builtins.int
    """"""
    parts: builtins.int
    """"""
    stat_view: builtins.int
    """"""
    stat_reply: builtins.int
    """"""
    state: builtins.int
    """"""
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        title: builtins.str = ...,
        owner: global___PickArchiveAuthor | None = ...,
        cover: builtins.str = ...,
        duration: builtins.int = ...,
        parts: builtins.int = ...,
        stat_view: builtins.int = ...,
        stat_reply: builtins.int = ...,
        state: builtins.int = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "owner", b"owner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "duration", b"duration", "item", b"item", "message", b"message", "owner", b"owner", "parts", b"parts", "stat_reply", b"stat_reply", "stat_view", b"stat_view", "state", b"state", "title", b"title"]) -> None: ...

global___PickArchive = PickArchive

@typing_extensions.final
class PickArchiveAuthor(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "name", b"name"]) -> None: ...

global___PickArchiveAuthor = PickArchiveAuthor

@typing_extensions.final
class PickCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PICK_ID_FIELD_NUMBER: builtins.int
    CARD_ID_FIELD_NUMBER: builtins.int
    CARD_NAME_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    pick_id: builtins.int
    """"""
    card_id: builtins.int
    """"""
    card_name: builtins.str
    """"""
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CardModule]:
        """"""
    def __init__(
        self,
        *,
        pick_id: builtins.int = ...,
        card_id: builtins.int = ...,
        card_name: builtins.str = ...,
        modules: collections.abc.Iterable[global___CardModule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_id", b"card_id", "card_name", b"card_name", "modules", b"modules", "pick_id", b"pick_id"]) -> None: ...

global___PickCard = PickCard

@typing_extensions.final
class PickCardDetailReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_ID_FIELD_NUMBER: builtins.int
    PICK_ID_FIELD_NUMBER: builtins.int
    card_id: builtins.int
    """"""
    pick_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        card_id: builtins.int = ...,
        pick_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_id", b"card_id", "pick_id", b"pick_id"]) -> None: ...

global___PickCardDetailReq = PickCardDetailReq

@typing_extensions.final
class PickCardDetailResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_ID_FIELD_NUMBER: builtins.int
    PICK_ID_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    card_id: builtins.int
    """"""
    pick_id: builtins.int
    """"""
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CardModule]:
        """"""
    def __init__(
        self,
        *,
        card_id: builtins.int = ...,
        pick_id: builtins.int = ...,
        modules: collections.abc.Iterable[global___CardModule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_id", b"card_id", "modules", b"modules", "pick_id", b"pick_id"]) -> None: ...

global___PickCardDetailResp = PickCardDetailResp

@typing_extensions.final
class PickFeedReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """"""
    def __init__(
        self,
        *,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset", b"offset"]) -> None: ...

global___PickFeedReq = PickFeedReq

@typing_extensions.final
class PickFeedResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFSET_FIELD_NUMBER: builtins.int
    CARDS_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """"""
    @property
    def cards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PickCard]:
        """"""
    def __init__(
        self,
        *,
        offset: builtins.int = ...,
        cards: collections.abc.Iterable[global___PickCard] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cards", b"cards", "offset", b"offset"]) -> None: ...

global___PickFeedResp = PickFeedResp

@typing_extensions.final
class PkcmArchive(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    PICK_REASON_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> global___PickArchive:
        """"""
    pick_reason: builtins.str
    """"""
    def __init__(
        self,
        *,
        arc: global___PickArchive | None = ...,
        pick_reason: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "pick_reason", b"pick_reason"]) -> None: ...

global___PkcmArchive = PkcmArchive

@typing_extensions.final
class PkcmCenterButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_HEAD_FIELD_NUMBER: builtins.int
    ICON_TAIL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    icon_head: builtins.str
    """"""
    icon_tail: builtins.str
    """"""
    title: builtins.str
    """"""
    uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_head: builtins.str = ...,
        icon_tail: builtins.str = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_head", b"icon_head", "icon_tail", b"icon_tail", "title", b"title", "uri", b"uri"]) -> None: ...

global___PkcmCenterButton = PkcmCenterButton

@typing_extensions.final
class PkcmHeader(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BTN_ICON_FIELD_NUMBER: builtins.int
    BTN_TEXT_FIELD_NUMBER: builtins.int
    BTN_URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    btn_icon: builtins.str
    """"""
    btn_text: builtins.str
    """"""
    btn_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        btn_icon: builtins.str = ...,
        btn_text: builtins.str = ...,
        btn_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["btn_icon", b"btn_icon", "btn_text", b"btn_text", "btn_uri", b"btn_uri", "desc", b"desc", "title", b"title"]) -> None: ...

global___PkcmHeader = PkcmHeader

@typing_extensions.final
class PlayActionReportReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    from_spmid: builtins.str
    """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        from_spmid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_spmid", b"from_spmid", "item", b"item"]) -> None: ...

global___PlayActionReportReq = PlayActionReportReq

@typing_extensions.final
class PlayDASH(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    MIN_BUFFER_TIME_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    duration: builtins.int
    """"""
    min_buffer_time: builtins.float
    """"""
    @property
    def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """"""
    def __init__(
        self,
        *,
        duration: builtins.int = ...,
        min_buffer_time: builtins.float = ...,
        audio: collections.abc.Iterable[global___DashItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "duration", b"duration", "min_buffer_time", b"min_buffer_time"]) -> None: ...

global___PlayDASH = PlayDASH

@typing_extensions.final
class PlayHistoryAddReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PLAY_STYLE_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    progress: builtins.int
    """"""
    duration: builtins.int
    """"""
    play_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        play_style: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "item", b"item", "play_style", b"play_style", "progress", b"progress"]) -> None: ...

global___PlayHistoryAddReq = PlayHistoryAddReq

@typing_extensions.final
class PlayHistoryDelReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    TRUNCATE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayItem]:
        """"""
    truncate: builtins.bool
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___PlayItem] | None = ...,
        truncate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "truncate", b"truncate"]) -> None: ...

global___PlayHistoryDelReq = PlayHistoryDelReq

@typing_extensions.final
class PlayHistoryReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_OPT_FIELD_NUMBER: builtins.int
    LOCAL_TODAY_ZERO_FIELD_NUMBER: builtins.int
    @property
    def page_opt(self) -> global___PageOption:
        """"""
    local_today_zero: builtins.int
    """"""
    def __init__(
        self,
        *,
        page_opt: global___PageOption | None = ...,
        local_today_zero: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["page_opt", b"page_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_today_zero", b"local_today_zero", "page_opt", b"page_opt"]) -> None: ...

global___PlayHistoryReq = PlayHistoryReq

@typing_extensions.final
class PlayHistoryResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    REACH_END_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    total: builtins.int
    """"""
    reach_end: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetailItem]:
        """"""
    def __init__(
        self,
        *,
        total: builtins.int = ...,
        reach_end: builtins.bool = ...,
        list: collections.abc.Iterable[global___DetailItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "reach_end", b"reach_end", "total", b"total"]) -> None: ...

global___PlayHistoryResp = PlayHistoryResp

@typing_extensions.final
class PlayInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    QN_TYPE_FIELD_NUMBER: builtins.int
    PLAY_URL_FIELD_NUMBER: builtins.int
    PLAY_DASH_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORMATS_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """"""
    format: builtins.str
    """"""
    qn_type: builtins.int
    """"""
    @property
    def play_url(self) -> global___PlayURL:
        """"""
    @property
    def play_dash(self) -> global___PlayDASH:
        """"""
    fnver: builtins.int
    fnval: builtins.int
    """"""
    @property
    def formats(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    video_codecid: builtins.int
    """"""
    length: builtins.int
    """"""
    code: builtins.int
    """"""
    message: builtins.str
    """"""
    expire_time: builtins.int
    """"""
    @property
    def volume(self) -> bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.VolumeInfo:
        """"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        format: builtins.str = ...,
        qn_type: builtins.int = ...,
        play_url: global___PlayURL | None = ...,
        play_dash: global___PlayDASH | None = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        formats: collections.abc.Iterable[builtins.int] | None = ...,
        video_codecid: builtins.int = ...,
        length: builtins.int = ...,
        code: builtins.int = ...,
        message: builtins.str = ...,
        expire_time: builtins.int = ...,
        volume: bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2.VolumeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info", "play_dash", b"play_dash", "play_url", b"play_url", "volume", b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "expire_time", b"expire_time", "fnval", b"fnval", "fnver", b"fnver", "format", b"format", "formats", b"formats", "info", b"info", "length", b"length", "message", b"message", "play_dash", b"play_dash", "play_url", b"play_url", "qn", b"qn", "qn_type", b"qn_type", "video_codecid", b"video_codecid", "volume", b"volume"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["info", b"info"]) -> typing_extensions.Literal["play_url", "play_dash"] | None: ...

global___PlayInfo = PlayInfo

@typing_extensions.final
class PlayItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SUB_ID_FIELD_NUMBER: builtins.int
    ET_FIELD_NUMBER: builtins.int
    item_type: builtins.int
    """"""
    oid: builtins.int
    """"""
    @property
    def sub_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    @property
    def et(self) -> global___EventTracking:
        """"""
    def __init__(
        self,
        *,
        item_type: builtins.int = ...,
        oid: builtins.int = ...,
        sub_id: collections.abc.Iterable[builtins.int] | None = ...,
        et: global___EventTracking | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["et", b"et"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["et", b"et", "item_type", b"item_type", "oid", b"oid", "sub_id", b"sub_id"]) -> None: ...

global___PlayItem = PlayItem

@typing_extensions.final
class PlaylistAddReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    AFTER_FIELD_NUMBER: builtins.int
    HEAD_FIELD_NUMBER: builtins.int
    TAIL_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayItem]:
        """"""
    @property
    def after(self) -> global___PlayItem:
        """"""
    head: builtins.bool
    """"""
    tail: builtins.bool
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___PlayItem] | None = ...,
        after: global___PlayItem | None = ...,
        head: builtins.bool = ...,
        tail: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["after", b"after", "head", b"head", "pos", b"pos", "tail", b"tail"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["after", b"after", "head", b"head", "items", b"items", "pos", b"pos", "tail", b"tail"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["pos", b"pos"]) -> typing_extensions.Literal["after", "head", "tail"] | None: ...

global___PlaylistAddReq = PlaylistAddReq

@typing_extensions.final
class PlaylistDelReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    TRUNCATE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayItem]:
        """"""
    truncate: builtins.bool
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___PlayItem] | None = ...,
        truncate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "truncate", b"truncate"]) -> None: ...

global___PlaylistDelReq = PlaylistDelReq

@typing_extensions.final
class PlaylistReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ANCHOR_FIELD_NUMBER: builtins.int
    PAGE_OPT_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    EXTRA_ID_FIELD_NUMBER: builtins.int
    SORT_OPT_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    @property
    def anchor(self) -> global___PlayItem:
        """"""
    @property
    def page_opt(self) -> global___PageOption:
        """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    extra_id: builtins.int
    """"""
    @property
    def sort_opt(self) -> global___SortOption:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        anchor: global___PlayItem | None = ...,
        page_opt: global___PageOption | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        extra_id: builtins.int = ...,
        sort_opt: global___SortOption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["anchor", b"anchor", "page_opt", b"page_opt", "player_args", b"player_args", "sort_opt", b"sort_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor", b"anchor", "extra_id", b"extra_id", "from", b"from", "id", b"id", "page_opt", b"page_opt", "player_args", b"player_args", "sort_opt", b"sort_opt"]) -> None: ...

global___PlaylistReq = PlaylistReq

@typing_extensions.final
class PlaylistResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    REACH_START_FIELD_NUMBER: builtins.int
    REACH_END_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    LAST_PLAY_FIELD_NUMBER: builtins.int
    LAST_PROGRESS_FIELD_NUMBER: builtins.int
    total: builtins.int
    """"""
    reach_start: builtins.bool
    """"""
    reach_end: builtins.bool
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetailItem]:
        """"""
    @property
    def last_play(self) -> global___PlayItem:
        """"""
    last_progress: builtins.int
    """"""
    def __init__(
        self,
        *,
        total: builtins.int = ...,
        reach_start: builtins.bool = ...,
        reach_end: builtins.bool = ...,
        list: collections.abc.Iterable[global___DetailItem] | None = ...,
        last_play: global___PlayItem | None = ...,
        last_progress: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_play", b"last_play"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_play", b"last_play", "last_progress", b"last_progress", "list", b"list", "reach_end", b"reach_end", "reach_start", b"reach_start", "total", b"total"]) -> None: ...

global___PlaylistResp = PlaylistResp

@typing_extensions.final
class PlayURL(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURL_FIELD_NUMBER: builtins.int
    @property
    def durl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """"""
    def __init__(
        self,
        *,
        durl: collections.abc.Iterable[global___ResponseUrl] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["durl", b"durl"]) -> None: ...

global___PlayURL = PlayURL

@typing_extensions.final
class PlayURLReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "player_args", b"player_args"]) -> None: ...

global___PlayURLReq = PlayURLReq

@typing_extensions.final
class PlayURLResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlayerInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___PlayInfo: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___PlayInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ITEM_FIELD_NUMBER: builtins.int
    PLAYABLE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    PLAYERINFO_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    playable: builtins.int
    """"""
    message: builtins.str
    """"""
    @property
    def playerInfo(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___PlayInfo]:
        """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        playable: builtins.int = ...,
        message: builtins.str = ...,
        playerInfo: collections.abc.Mapping[builtins.int, global___PlayInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "message", b"message", "playable", b"playable", "playerInfo", b"playerInfo"]) -> None: ...

global___PlayURLResp = PlayURLResp

@typing_extensions.final
class RcmdPlaylistReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NEED_HISTORY_FIELD_NUMBER: builtins.int
    NEED_TOP_CARDS_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    need_history: builtins.bool
    """"""
    need_top_cards: builtins.bool
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        need_history: builtins.bool = ...,
        need_top_cards: builtins.bool = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "id", b"id", "need_history", b"need_history", "need_top_cards", b"need_top_cards", "player_args", b"player_args"]) -> None: ...

global___RcmdPlaylistReq = RcmdPlaylistReq

@typing_extensions.final
class RcmdPlaylistResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    HISTORY_LEN_FIELD_NUMBER: builtins.int
    TOP_CARDS_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DetailItem]:
        """"""
    history_len: builtins.int
    """"""
    @property
    def top_cards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopCard]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___DetailItem] | None = ...,
        history_len: builtins.int = ...,
        top_cards: collections.abc.Iterable[global___TopCard] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["history_len", b"history_len", "list", b"list", "top_cards", b"top_cards"]) -> None: ...

global___RcmdPlaylistResp = RcmdPlaylistResp

@typing_extensions.final
class ResponseUrl(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    AHEAD_FIELD_NUMBER: builtins.int
    VHEAD_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    order: builtins.int
    """"""
    length: builtins.int
    """"""
    size: builtins.int
    """"""
    ahead: builtins.str
    """"""
    vhead: builtins.str
    """"""
    url: builtins.str
    """"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    md5: builtins.str
    """"""
    def __init__(
        self,
        *,
        order: builtins.int = ...,
        length: builtins.int = ...,
        size: builtins.int = ...,
        ahead: builtins.str = ...,
        vhead: builtins.str = ...,
        url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        md5: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ahead", b"ahead", "backup_url", b"backup_url", "length", b"length", "md5", b"md5", "order", b"order", "size", b"size", "url", b"url", "vhead", b"vhead"]) -> None: ...

global___ResponseUrl = ResponseUrl

@typing_extensions.final
class SortOption(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    SORT_FIELD_FIELD_NUMBER: builtins.int
    order: builtins.int
    """"""
    sort_field: builtins.int
    """"""
    def __init__(
        self,
        *,
        order: builtins.int = ...,
        sort_field: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["order", b"order", "sort_field", b"sort_field"]) -> None: ...

global___SortOption = SortOption

@typing_extensions.final
class ThumbUpReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "item", b"item"]) -> None: ...

global___ThumbUpReq = ThumbUpReq

@typing_extensions.final
class ThumbUpResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___ThumbUpResp = ThumbUpResp

@typing_extensions.final
class TopCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    PLAY_STYLE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    LISTEN_HISTORY_FIELD_NUMBER: builtins.int
    FAV_FOLDER_FIELD_NUMBER: builtins.int
    UP_RECALL_FIELD_NUMBER: builtins.int
    PICK_TODAY_FIELD_NUMBER: builtins.int
    POS_FIELD_NUMBER: builtins.int
    TITLE_ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    play_style: builtins.int
    """"""
    card_type: builtins.int
    """"""
    @property
    def listen_history(self) -> global___TpcdHistory:
        """"""
    @property
    def fav_folder(self) -> global___TpcdFavFolder:
        """"""
    @property
    def up_recall(self) -> global___TpcdUpRecall:
        """"""
    @property
    def pick_today(self) -> global___TpcdPickToday:
        """"""
    pos: builtins.int
    """"""
    title_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        play_style: builtins.int = ...,
        card_type: builtins.int = ...,
        listen_history: global___TpcdHistory | None = ...,
        fav_folder: global___TpcdFavFolder | None = ...,
        up_recall: global___TpcdUpRecall | None = ...,
        pick_today: global___TpcdPickToday | None = ...,
        pos: builtins.int = ...,
        title_icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card", b"card", "fav_folder", b"fav_folder", "listen_history", b"listen_history", "pick_today", b"pick_today", "up_recall", b"up_recall"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card", b"card", "card_type", b"card_type", "fav_folder", b"fav_folder", "listen_history", b"listen_history", "pick_today", b"pick_today", "play_style", b"play_style", "pos", b"pos", "title", b"title", "title_icon", b"title_icon", "up_recall", b"up_recall"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card", b"card"]) -> typing_extensions.Literal["listen_history", "fav_folder", "up_recall", "pick_today"] | None: ...

global___TopCard = TopCard

@typing_extensions.final
class TpcdFavFolder(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    FID_FIELD_NUMBER: builtins.int
    FOLDER_TYPE_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DetailItem:
        """"""
    text: builtins.str
    """"""
    pic: builtins.str
    """"""
    fid: builtins.int
    """"""
    folder_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___DetailItem | None = ...,
        text: builtins.str = ...,
        pic: builtins.str = ...,
        fid: builtins.int = ...,
        folder_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fid", b"fid", "folder_type", b"folder_type", "item", b"item", "pic", b"pic", "text", b"text"]) -> None: ...

global___TpcdFavFolder = TpcdFavFolder

@typing_extensions.final
class TpcdHistory(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DetailItem:
        """"""
    text: builtins.str
    """"""
    pic: builtins.str
    """"""
    def __init__(
        self,
        *,
        item: global___DetailItem | None = ...,
        text: builtins.str = ...,
        pic: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "pic", b"pic", "text", b"text"]) -> None: ...

global___TpcdHistory = TpcdHistory

@typing_extensions.final
class TpcdPickToday(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    PICK_ID_FIELD_NUMBER: builtins.int
    PICK_CARD_ID_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___DetailItem:
        """"""
    text: builtins.str
    """"""
    pic: builtins.str
    """"""
    pick_id: builtins.int
    """"""
    pick_card_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        item: global___DetailItem | None = ...,
        text: builtins.str = ...,
        pic: builtins.str = ...,
        pick_id: builtins.int = ...,
        pick_card_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item", "pic", b"pic", "pick_card_id", b"pick_card_id", "pick_id", b"pick_id", "text", b"text"]) -> None: ...

global___TpcdPickToday = TpcdPickToday

@typing_extensions.final
class TpcdUpRecall(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_MID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    MEDIALIST_TYPE_FIELD_NUMBER: builtins.int
    MEDIALIST_BIZ_ID_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    up_mid: builtins.int
    """"""
    text: builtins.str
    """"""
    avatar: builtins.str
    """"""
    medialist_type: builtins.int
    """"""
    medialist_biz_id: builtins.int
    """"""
    @property
    def item(self) -> global___DetailItem:
        """"""
    def __init__(
        self,
        *,
        up_mid: builtins.int = ...,
        text: builtins.str = ...,
        avatar: builtins.str = ...,
        medialist_type: builtins.int = ...,
        medialist_biz_id: builtins.int = ...,
        item: global___DetailItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "item", b"item", "medialist_biz_id", b"medialist_biz_id", "medialist_type", b"medialist_type", "text", b"text", "up_mid", b"up_mid"]) -> None: ...

global___TpcdUpRecall = TpcdUpRecall

@typing_extensions.final
class TripleLikeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> global___PlayItem:
        """"""
    def __init__(
        self,
        *,
        item: global___PlayItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["item", b"item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["item", b"item"]) -> None: ...

global___TripleLikeReq = TripleLikeReq

@typing_extensions.final
class TripleLikeResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    THUMB_OK_FIELD_NUMBER: builtins.int
    COIN_OK_FIELD_NUMBER: builtins.int
    FAV_OK_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    thumb_ok: builtins.bool
    """"""
    coin_ok: builtins.bool
    """"""
    fav_ok: builtins.bool
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        thumb_ok: builtins.bool = ...,
        coin_ok: builtins.bool = ...,
        fav_ok: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin_ok", b"coin_ok", "fav_ok", b"fav_ok", "message", b"message", "thumb_ok", b"thumb_ok"]) -> None: ...

global___TripleLikeResp = TripleLikeResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """空回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class PlayerOnlineReply(google.protobuf.message.Message):
    """获取在线人数-回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_TEXT_FIELD_NUMBER: builtins.int
    SEC_NEXT_FIELD_NUMBER: builtins.int
    BOTTOM_SHOW_FIELD_NUMBER: builtins.int
    SDM_SHOW_FIELD_NUMBER: builtins.int
    SDM_TEXT_FIELD_NUMBER: builtins.int
    TOTAL_NUMBER_FIELD_NUMBER: builtins.int
    TOTAL_NUMBER_TEXT_FIELD_NUMBER: builtins.int
    total_text: builtins.str
    """"""
    sec_next: builtins.int
    """下次轮询间隔时间"""
    bottom_show: builtins.bool
    """是否底部显示"""
    sdm_show: builtins.bool
    """"""
    sdm_text: builtins.str
    """"""
    total_number: builtins.int
    """"""
    total_number_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        total_text: builtins.str = ...,
        sec_next: builtins.int = ...,
        bottom_show: builtins.bool = ...,
        sdm_show: builtins.bool = ...,
        sdm_text: builtins.str = ...,
        total_number: builtins.int = ...,
        total_number_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_show", b"bottom_show", "sdm_show", b"sdm_show", "sdm_text", b"sdm_text", "sec_next", b"sec_next", "total_number", b"total_number", "total_number_text", b"total_number_text", "total_text", b"total_text"]) -> None: ...

global___PlayerOnlineReply = PlayerOnlineReply

@typing_extensions.final
class PlayerOnlineReq(google.protobuf.message.Message):
    """获取在线人数-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PLAY_OPEN_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件 avid"""
    cid: builtins.int
    """视频 cid"""
    play_open: builtins.bool
    """是否在播放中"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        play_open: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "play_open", b"play_open"]) -> None: ...

global___PlayerOnlineReq = PlayerOnlineReq

@typing_extensions.final
class PremiereInfoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREMIERE_OVER_TEXT_FIELD_NUMBER: builtins.int
    PARTICIPANT_FIELD_NUMBER: builtins.int
    INTERACTION_FIELD_NUMBER: builtins.int
    premiere_over_text: builtins.str
    """"""
    participant: builtins.int
    """"""
    interaction: builtins.int
    """"""
    def __init__(
        self,
        *,
        premiere_over_text: builtins.str = ...,
        participant: builtins.int = ...,
        interaction: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interaction", b"interaction", "participant", b"participant", "premiere_over_text", b"premiere_over_text"]) -> None: ...

global___PremiereInfoReply = PremiereInfoReply

@typing_extensions.final
class PremiereInfoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid"]) -> None: ...

global___PremiereInfoReq = PremiereInfoReq

@typing_extensions.final
class ReportWatchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BIZ_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    biz: builtins.str
    """"""
    buvid: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        biz: builtins.str = ...,
        buvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "biz", b"biz", "buvid", b"buvid"]) -> None: ...

global___ReportWatchReq = ReportWatchReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/archive/middleware/v1/preload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0bilibili/app/archive/middleware/v1/preload.proto\x12\"bilibili.app.archive.middleware.v1\"a\n\nPlayerArgs\x12\n\n\x02qn\x18\x01 \x01(\x03\x12\r\n\x05\x66nver\x18\x02 \x01(\x03\x12\r\n\x05\x66nval\x18\x03 \x01(\x03\x12\x12\n\nforce_host\x18\x04 \x01(\x03\x12\x15\n\rvoice_balance\x18\x05 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.archive.middleware.v1.preload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLAYERARGS']._serialized_start=88
  _globals['_PLAYERARGS']._serialized_end=185
# @@protoc_insertion_point(module_scope)
